==> com.liferay.dynamic.data.mapping.form.renderer-4.0.75.jar: META-INF/resources/js/containers/Pagination/Pagination.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@4.0.75/js/containers/Pagination/Pagination.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './Pagination.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _Pagination = _interopRequireDefault(require("./Pagination.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var Pagination = /*#__PURE__*/function (_Component) {
    _inherits(Pagination, _Component);

    function Pagination() {
      _classCallCheck(this, Pagination);

      return _possibleConstructorReturn(this, _getPrototypeOf(Pagination).apply(this, arguments));
    }

    _createClass(Pagination, [{
      key: "_handleItemClicked",
      value: function _handleItemClicked(_ref) {
        var dataset = _ref.delegateTarget.dataset;
        var dispatch = this.context.dispatch;
        var pageIndex = dataset.pageIndex;
        dispatch('paginationItemClicked', {
          pageIndex: Number(pageIndex)
        });
      }
    }, {
      key: "_handleNextClicked",
      value: function _handleNextClicked() {
        var dispatch = this.context.dispatch;
        dispatch('paginationNextClicked');
      }
    }, {
      key: "_handlePreviousClicked",
      value: function _handlePreviousClicked() {
        var dispatch = this.context.dispatch;
        dispatch('paginationPreviousClicked');
      }
    }]);

    return Pagination;
  }(_metalComponent["default"]);

  _metalSoy["default"].register(Pagination, _Pagination["default"]);

  var _default = Pagination;
  exports["default"] = _default;
  //# sourceMappingURL=Pagination.es.js.map
});
//# sourceMappingURL=Pagination.es.js.map

==> com.liferay.dynamic.data.mapping.form.renderer-5.0.2.jar: META-INF/resources/js/containers/Pagination/Pagination.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@5.0.2/js/containers/Pagination/Pagination.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './Pagination.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _PaginationSoy = _interopRequireDefault(require("./Pagination.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var Pagination =
  /*#__PURE__*/
  function (_Component) {
    _inherits(Pagination, _Component);

    function Pagination() {
      _classCallCheck(this, Pagination);

      return _possibleConstructorReturn(this, _getPrototypeOf(Pagination).apply(this, arguments));
    }

    _createClass(Pagination, [{
      key: "_handleItemClicked",
      value: function _handleItemClicked(_ref) {
        var dataset = _ref.delegateTarget.dataset;
        var dispatch = this.context.dispatch;
        var pageIndex = dataset.pageIndex;
        dispatch('paginationItemClicked', {
          pageIndex: Number(pageIndex)
        });
      }
    }, {
      key: "_handleNextClicked",
      value: function _handleNextClicked() {
        var dispatch = this.context.dispatch;
        dispatch('paginationNextClicked');
      }
    }, {
      key: "_handlePreviousClicked",
      value: function _handlePreviousClicked() {
        var dispatch = this.context.dispatch;
        dispatch('paginationPreviousClicked');
      }
    }]);

    return Pagination;
  }(_metalComponent["default"]);

  _metalSoy["default"].register(Pagination, _PaginationSoy["default"]);

  var _default = Pagination;
  exports["default"] = _default;
  //# sourceMappingURL=Pagination.es.js.map
});
//# sourceMappingURL=Pagination.es.js.map
